@@ -14,11 +14,11 @@ from jamboree.handlers.default import MultiDataManagement
 from jamboree.handlers.default.data import DataHandler
 from loguru import logger
 
-
-from linktt_end.handlers.allocation import AllocationHandler
-from linktt_end.utils.slippage import RandomUniformSlippageModel
-from linktt_end.utils.trades.trade import Trade, DynamicTrade, TradeType
-from linktt_end.data import PriceGenerator
+# from linktt_end.handlers.allocation import AllocationHandler
+from linkkt_end.handlers.allocation import AllocationHandler
+from linkkt_end.utils.slippage import RandomUniformSlippageModel
+from linkkt_end.utils.trades.trade import Trade, DynamicTrade, TradeType
+from linkkt_end.data import PriceGenerator
 
 
 
@@ -192,12 +192,12 @@ class PortfolioHandler(DBHandler):
     def performance(self):
         """ Get the performance of the user/exchange"""
         if self.has_updated == True:
-            return self.placeholders.get("portfolio", {})
+            return self.placeholders.get("performance", {})
         performance = self.load_performance()
         if isinstance(performance, dict):
             performance = [performance]
         
-        filtration_list = ['user_id', "episode", 'type', 'detail', 'exchange', 'live', 'timestamp', 'event_id']
+        filtration_list = ['user_id', 'episode', 'type', 'timestamp', 'exchange', 'live', 'session', 'time', 'event_id']
         
         performance_filtered = list(map(lambda x: omit(filtration_list, x), performance))
         return performance_filtered
@@ -206,10 +206,13 @@ class PortfolioHandler(DBHandler):
     @property
     def portfolio(self):
         """ Get the latest portfolio of the user/exchange"""
-        if self.has_updated:
+        if self.has_updated == True:
             return self.placeholders.get("portfolio", {})
-        portfolio = self.latest_portfolio()
-        filtered_portfolio = omit(['user_id', 'episode', 'type', 'timestamp', 'event_id'], portfolio) 
+        _portfolio = self.latest_portfolio()
+        filtered_portfolio = omit(
+            ['user_id', 'episode', 'type', 'timestamp', 'exchange', 'live', 'session', 'time', 'event_id'], 
+            _portfolio
+        )
         return filtered_portfolio
             
     @property
@@ -281,14 +284,37 @@ class PortfolioHandler(DBHandler):
         self._data.episode = episode
         self._data.live = live
         self._data.processor = self.processor
-        datasets = copy.copy(self._data.datasets)
-        
-        self.sim_only_data(datasets)
+        # self._data.reset()
         return self._data
 
+    def is_user_asset(self, asset:dict):
+        """ Determines if the given asset is indeed the user's"""
+        asset_keys = asset.keys()
+        if len(asset_keys) == 0:
+            return False
+        
+
+        # TODO: Fix the source of this
+        if 'episode' in asset_keys:
+            episode = asset.pop('episode', None)
+            asset['subcategories']['episode'] = episode
+
+        current_user_assets = self.users_assets
+
+        if len(current_user_assets) == 0:
+            return False
+        hashed_comparision_asset = self.main_helper.generate_hash(asset)
+        comparison_hashed_assets = [
+            self.main_helper.generate_hash(x) for x in current_user_assets
+        ]
+        return hashed_comparision_asset in comparison_hashed_assets
 
     @property
-    def allocation(self):
+    def users_assets(self) -> list:
+        return self.pricing.sources
+
+    @property
+    def allocation(self) -> dict:
         if self.has_updated:
             return self.placeholders.get("allocation", {})    
         allocator = self.allocator.allocation
@@ -333,7 +359,8 @@ class PortfolioHandler(DBHandler):
 
 
     def get_count(self) -> int:
-        count = self.count()
+        alt = {"detail": "portfolio"}
+        count = self.count(alt=alt)
         return count
 
 
@@ -355,10 +382,11 @@ class PortfolioHandler(DBHandler):
 
 
     def latest_portfolio(self):
+        alt = {"detail": "portfolio"}
         if self.is_live == True:
-            last_state = self.last(ar="absolute")
+            last_state = self.last(alt=alt, ar="absolute")
             return last_state
-        last_state = self.last(ar="relative")
+        last_state = self.last(alt=alt, ar="relative")
         return last_state
 
     def latest_performance(self):
@@ -384,10 +412,11 @@ class PortfolioHandler(DBHandler):
     
     
     def load_portfolio(self):
+        alt = {"detail": "portfolio"}
         if self.is_live == True:
-            portfolio = self.many(self.limit, ar="absolute")
+            portfolio = self.many(self.limit, alt=alt, ar="absolute")
         else:
-            portfolio = self.many(self.limit, ar="relative")
+            portfolio = self.many(self.limit, alt=alt, ar="relative")
         if isinstance(portfolio, dict):
             return [portfolio]
         return portfolio
@@ -417,6 +446,7 @@ class PortfolioHandler(DBHandler):
 
     def load_placeholders(self):
         if self.has_updated == False:
+            # pass
             self.placeholders['portfolio'] = self.portfolio
             self.placeholders['balance'] = float(self.balance)
             self.placeholders['holdings'] = self.holdings
@@ -717,6 +747,7 @@ class PortfolioHandler(DBHandler):
         if self.is_sim:
             combined_dict["subcategories"]['episode'] = self['episode']
         self.pricing.add_multiple_data_sources([combined_dict])
+        # logger.info(self.pricing.sources)
 
 
     def remove_asset(self, name, subcategories={}):
@@ -786,11 +817,14 @@ class PortfolioHandler(DBHandler):
                 net_worth = self.net_worth
                 portfolio = self.portfolio
                 price = self.current_price(symbol=trade.symbol)
+                allocation = self.allocation
                 amount = float(portfolio.get(trade.symbol, 0.0)) # how many of this given asset do we have
                 
+                cap_pct = allocation.get(trade.symbol, 0.000000000000000000001)
+                
 
                 dynamic_trade = copy.copy(trade)
-
+                dynamic_trade.cap_pct = cap_pct
                 
                 dynamic_trade.amount = float(amount)
                 dynamic_trade.price = (float(price) + 0.00000000000001)
@@ -821,7 +855,6 @@ class PortfolioHandler(DBHandler):
         self.load_placeholders()
         self.step_trade(trade)
 
-        logger.warning("Taking a step")
         final_dict['done'] = (not self.pricing.is_next)
         # we'd put all of the portfolio information here by asset. 
         final_dict['obs']["portfolio"] = {}
