@@ -1,5 +1,5 @@
 import numpy
-from linkkt_e2e_handlers.stochastic import brownian_motion_log_returns
+from linkkt_end.stochastic import brownian_motion_log_returns
 
 def ornstein_uhlenbeck_levels(param):
     """
